# NavierStokes

description

## Table of Contents
* [Getting Started](#getting-started)
* [Acknowledgements](#acknowledgements)

## Getting Started

### Prerequisites

### Installing

## Running the tests
```python
python -m unittest tests.test_test
```

## Deployment

## Built With

## Contributing

## Versioning
I use [SemVer](https://semver.org) for versioning.
For the versions available, see the [tags on this repository](https://github.com/rickykim93/NavierStokes/releases)

## Authors
* Kyu Mok (Ricky) Kim - Initial work - [website](https://rickykim.net), [github](https://github.com/rickykim93)

## License
This project is licensed under the MIT License - see the [License](https://github.com/rickykim93/NavierStokes/blob/master/LICENSE)
file for details.

## Acknowledgements
* MIE 1210: Computational Fluid Mechanics - Course from University of Toronto
for teaching me Navier Stokes equations and how to implement them
